==> zio-aws-iottwinmaker_2.13-5.20.42.1-sources.jar: zio/aws/iottwinmaker/model/ListWorkspacesResponse.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListWorkspacesResponse(
    workspaceSummaries: Optional[
      Iterable[zio.aws.iottwinmaker.model.WorkspaceSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse = {
    import ListWorkspacesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
      .builder()
      .optionallyWith(
        workspaceSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.workspaceSummaries)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ListWorkspacesResponse.wrap(buildAwsValue())
}
object ListWorkspacesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ListWorkspacesResponse =
      zio.aws.iottwinmaker.model.ListWorkspacesResponse(
        workspaceSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def workspaceSummaries
        : Optional[List[zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getWorkspaceSummaries: ZIO[Any, AwsError, List[
      zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("workspaceSummaries", workspaceSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ) extends zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly {
    override val workspaceSummaries
        : Optional[List[zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceSummaries())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iottwinmaker.model.WorkspaceSummary.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iottwinmaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ): zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iottwinmaker_3-5.17.186.1-sources.jar: zio/aws/iottwinmaker/model/ListWorkspacesResponse.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListWorkspacesResponse(
    nextToken: Optional[NextToken] = Optional.Absent,
    workspaceSummaries: Optional[
      Iterable[zio.aws.iottwinmaker.model.WorkspaceSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse = {
    import ListWorkspacesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        workspaceSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.workspaceSummaries)
      .build()
  }
  def asReadOnly: zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly =
    zio.aws.iottwinmaker.model.ListWorkspacesResponse.wrap(buildAwsValue())
}
object ListWorkspacesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.ListWorkspacesResponse =
      zio.aws.iottwinmaker.model.ListWorkspacesResponse(
        nextToken.map(value => value),
        workspaceSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Optional[NextToken]
    def workspaceSummaries
        : Optional[List[zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getWorkspaceSummaries: ZIO[Any, AwsError, List[
      zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("workspaceSummaries", workspaceSummaries)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ) extends zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly {
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iottwinmaker.model.primitives.NextToken(value))
    override val workspaceSummaries
        : Optional[List[zio.aws.iottwinmaker.model.WorkspaceSummary.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceSummaries())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iottwinmaker.model.WorkspaceSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.ListWorkspacesResponse
  ): zio.aws.iottwinmaker.model.ListWorkspacesResponse.ReadOnly = new Wrapper(
    impl
  )
}
